<?php

namespace Drupal\Tests\acquia_contenthub_publisher\Kernel;

use Acquia\ContentHubClient\ContentHubClient;
use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Client\ClientFactory;
use Drupal\acquia_contenthub_publisher\Form\Webhook\WebhookDeleteConfirmForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\KernelTests\KernelTestBase;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * ContentHubDeleteFiltersTest tests deletion of filters..
 *
 * @group acquia_contenthub_publisher
 *
 * @package Drupal\Tests\acquia_contenthub_publisher
 *
 * @coversDefaultClass \Drupal\acquia_contenthub_publisher\ContentHubExportLogger
 */
class ContentHubDeleteFiltersTest extends KernelTestBase {

  use ProphecyTrait;

  /**
   * Tests that client's deleteFilter method is not invoked.
   */
  public function testFailureEventLogging(): void {
    $client = $this->prophesize(ContentHubClient::class);
    // Since filter is not set, deleteFilter method should not be called.
    $client->deleteFilter(Argument::any())->shouldNotBeCalled();
    $client_factory = $this->prophesize(ClientFactory::class);
    $client_factory->getClient()->willReturn($client->reveal());

    $dispatcher = $this->prophesize(EventDispatcherInterface::class);
    $dispatcher->dispatch(Argument::any(), AcquiaContentHubEvents::ACH_UNREGISTER)->will(function ($args) {
      /** @var \Drupal\acquia_contenthub\Event\AcquiaContentHubUnregisterEvent $event */
      $event = $args[0];
      $event->setDefaultFilter('');
      return $event;
    });

    $form = new WebhookDeleteConfirmForm($client_factory->reveal(), $dispatcher->reveal());
    $form_state = $this->prophesize(FormStateInterface::class);

    $form->buildForm([], $form_state->reveal(), 'webhook-uuid');
    $form->deleteFilters();
  }

}
