<?php

namespace Drupal\Tests\acquia_contenthub_publisher\Kernel\Plugin\QueueWorker;

use Acquia\ContentHubClient\ContentHubClient;
use Acquia\ContentHubClient\Settings;
use Acquia\ContentHubClient\StatusCodes;
use Drupal\acquia_contenthub\Client\ClientFactory;
use Drupal\Core\Queue\SuspendQueueException;
use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use GuzzleHttp\Psr7\Response;
use Prophecy\Argument;

/**
 * @coversDefaultClass \Drupal\acquia_contenthub_publisher\Plugin\QueueWorker\ContentHubExportQueueWorker
 *
 * @group acquia_contenthub_publisher
 *
 * @requires module depcalc
 */
class ContentHubExportQueueWorkerTest extends EntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'acquia_contenthub',
    'acquia_contenthub_publisher',
    'depcalc',
    'editor',
    'node',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installSchema('acquia_contenthub_publisher', ['acquia_contenthub_publisher_export_tracking']);
  }

  /**
   * Tests if the queue process halts properly, without ContentHubClient.
   */
  public function testMaintenanceModeWithoutContentHubClient(): void {
    $client = $this->prophesize(ContentHubClient::class);
    $client->getSettings()->willReturn([]);
    /** @var \Drupal\acquia_contenthub_publisher\Plugin\QueueWorker\ContentHubExportQueueWorker $queue_worker */
    $queue_worker = $this->container->get('plugin.manager.queue_worker')->createInstance('acquia_contenthub_publish_export');

    $this->expectException(SuspendQueueException::class);
    $this->expectExceptionMessage('Acquia Content Hub client cannot be initialized.');
    $data = new \stdClass();
    $data->uuid = '49599fcd-1211-4e14-afe9-5ba1f751912e';
    $data->type = 'node';
    $queue_worker->processItem($data);
  }

  /**
   * Tests if the queue process halts properly upon maintenance mode.
   */
  public function testMaintenanceModeInterruption(): void {
    $client = $this->prophesize(ContentHubClient::class);
    $settings = $this->prophesize(Settings::class);
    $settings->getUuid()->willReturn('someuuid');
    $settings->getWebhook('uuid')->willReturn('09dca6ae-c5d1-4507-afc4-92cf6d025265');
    $client->getSettings()->willReturn($settings->reveal());

    $client->putEntities(Argument::cetera())->willReturn(new Response(503, [], json_encode([
      'error' => [
        'code' => StatusCodes::SERVICE_UNDER_MAINTENANCE,
        'message' => 'service under maintenance',
      ],
    ])));
    $client_factory = $this->prophesize(ClientFactory::class);
    $client_factory->getClient()->willReturn($client->reveal());

    $this->container->set('acquia_contenthub.client.factory', $client_factory->reveal());

    /** @var \Drupal\acquia_contenthub_publisher\Plugin\QueueWorker\ContentHubExportQueueWorker $queue_worker */
    $queue_worker = $this->container->get('plugin.manager.queue_worker')->createInstance('acquia_contenthub_publish_export');

    NodeType::create([
      'type' => 'test',
    ])->save();

    Node::create([
      'title' => 'test',
      'type' => 'test',
      'uuid' => '49599fcd-1211-4e14-afe9-5ba1f751912e',
    ])->save();

    $this->expectException(SuspendQueueException::class);
    $data = new \stdClass();
    $data->uuid = '49599fcd-1211-4e14-afe9-5ba1f751912e';
    $data->type = 'node';
    $queue_worker->processItem($data);
  }

}
